@@ -3,7 +3,7 @@ from pathlib import Path
 from datetime import datetime
 
 class logger:
-    def __init__(self, log_filepath=None, max_lines=10000):
+    def __init__(self, log_filepath=None, max_lines=100_000, level='info', name=None):
         filename = Path(sys.argv[0]).stem
         self.filename = filename
         if not log_filepath:
@@ -24,20 +24,26 @@ class logger:
         log_format = logging.Formatter(fmt='%(levelname)s - %(asctime)s.%(msecs)03d - Line %(lineno)s: %(message)s', datefmt='%Y-%m-%d %H:%M:%S')
         log_file.setFormatter(log_format)
 
-        coloredlogs.install(level=logging.INFO, logger=logger, fmt='%(message)s')
+        if level == 'info':
+            self.level = logging.INFO
+        elif level == 'debug':
+            self.level = logging.DEBUG
+        coloredlogs.install(level=self.level, logger=logger, fmt='%(message)s')
         self.logger = logger
 
         self.indent = ''
         
-        self.current_time('Starting', filename)
+        if not name:
+            name = filename
+        self.current_time('Starting', name)
         self.log()
 
-    def log(self, *items, level='info'):
+    def log(self, *items, level='info', beautify=True):
         message = ''
         for item in items:
             if message and '\n' not in message:
                 message += ' ' # Add space in between variables
-            if isinstance(item, dict) or isinstance(item, list):
+            if beautify and (isinstance(item, dict) or isinstance(item, list)):
                 try:
                     if message and '\n' not in message: # Add line breaks before and after
                         formatted_item = '\n'
@@ -52,7 +58,7 @@ class logger:
         if not message:
             log_format = logging.Formatter(fmt=self.indent + '%(message)s')
             self.log_file.setFormatter(log_format)
-            coloredlogs.install(level=logging.INFO, logger=self.logger, fmt='%(message)s')
+            coloredlogs.install(level=self.level, logger=self.logger, fmt='%(message)s')
 
         if level == 'info':
             self.logger.info(message)
@@ -68,7 +74,7 @@ class logger:
         if not message:
             log_format = logging.Formatter(fmt=self.indent + '%(levelname)s - %(asctime)s.%(msecs)03d - Line %(lineno)s: %(message)s', datefmt='%Y-%m-%d %H:%M:%S') # Reset to default log format
             self.log_file.setFormatter(log_format)
-            coloredlogs.install(level=logging.INFO, logger=self.logger, fmt=self.indent + '%(message)s') # Reset to default log format
+            coloredlogs.install(level=self.level, logger=self.logger, fmt=self.indent + '%(message)s') # Reset to default log format
 
         log_file = open(self.log_filepath, 'r+', encoding='utf-8', errors='ignore').read()
         number_of_lines = len(log_file.splitlines())
@@ -94,25 +100,21 @@ class logger:
         self.log(*items, level='warning')
     
     def current_time(self, *items, level='info'):
-        coloredlogs.install(level=logging.INFO, logger=self.logger, fmt=self.indent + '%(asctime)s.%(msecs)03d: %(message)s', datefmt='%H:%M:%S') # Add current time to printed log output format
-        self.log(*items, level=level)
-        coloredlogs.install(level=logging.INFO, logger=self.logger, fmt=self.indent + '%(message)s') # Reset to default log format
+        current_time = datetime.now()
+        current_time = current_time.strftime('%H:%M:%S:%f') + ':'
+        self.log(current_time, *items, level=level)
     
     def set_indent(self, indent=' - '):
-        self.indent = indent
         log_format = logging.Formatter(fmt=indent + '%(levelname)s - %(asctime)s.%(msecs)03d - Line %(lineno)s: %(message)s', datefmt='%Y-%m-%d %H:%M:%S')
         self.log_file.setFormatter(log_format)
-        coloredlogs.install(level=logging.INFO, logger=self.logger, fmt=indent + '%(message)s')
+        coloredlogs.install(level=self.level, logger=self.logger, fmt=indent + '%(message)s')
+        self.indent = indent
     
     def remove_indent(self):
-        self.indent = ''
         log_format = logging.Formatter(fmt='%(levelname)s - %(asctime)s.%(msecs)03d - Line %(lineno)s: %(message)s', datefmt='%Y-%m-%d %H:%M:%S')
         self.log_file.setFormatter(log_format)
-        coloredlogs.install(level=logging.INFO, logger=self.logger, fmt='%(message)s') # Reset to default log format
-
-    # def __del__(self):
-    #     self.log('Exiting', self.filename)
-    #     self.log()
+        coloredlogs.install(level=self.level, logger=self.logger, fmt='%(message)s') # Reset to default log format
+        self.indent = ''
 
 class printr:
     '''printr'''
